@@ -18,25 +18,24 @@ fn can_write_solomon_solution() {
             .add_customer((0, 0, 0, 0, 0, 1000, 1))
             .add_customer((1, 1, 0, 1, 5, 1000, 5))
             .build()
-            .read_solomon()
+            .read_solomon(false)
             .unwrap(),
     );
 
     let mut refinement_ctx = RefinementContext::new(
         problem.clone(),
-        Box::new(Elitism::new(problem.clone(), environment.random.clone(), 1, 1)),
+        Box::new(Elitism::new(problem.objective.clone(), environment.random.clone(), 1, 1)),
         environment.clone(),
         None,
     );
 
     let mut buffer = String::new();
     let writer = unsafe { BufWriter::new(buffer.as_mut_vec()) };
-    RecreateWithCheapest::default()
+    let solution = RecreateWithCheapest::default()
         .run(&mut refinement_ctx, InsertionContext::new(problem.clone(), environment))
         .solution
-        .to_solution(problem.extras.clone())
-        .write_solomon(writer)
-        .unwrap();
+        .to_solution(problem.extras.clone());
+    (&solution, 3.123456).write_solomon(writer).unwrap();
 
-    assert_eq!(buffer, "Solution\nRoute 1: 1\n");
+    assert_eq!(buffer, "Route 1: 1\nCost 3.12");
 }
